@@ -16,13 +16,14 @@
 #' @param nofl Logical. (GDAL >= 1.9.0) Only display the first file of the file list.
 #' @param sd Numeric. (GDAL >= 1.9.0) If the input dataset contains several subdatasets read and display a subdataset with specified number (starting from 1). This is an alternative of giving the full subdataset name.
 #' @param proj4 Logical. (GDAL >= 1.9.0) Report a PROJ.4 string corresponding to the file's coordinate system.
+#' @param oo Character. (starting with GDAL 2.0) NAME=VALUE. Dataset open option (format specific).
 #' @param version Logical. Report the version of GDAL and exit.
 #' @param formats Logical. List all raster formats supported by this GDAL build (read-only and read-write) and exit. The format support is indicated as follows: 'ro' is read-only driver; 'rw' is read or write (ie. supports CreateCopy); 'rw+' is read, write and update (ie. supports Create). A 'v' is appended for formats supporting virtual IO (/vsimem, /vsigzip, /vsizip, etc). A 's' is appended for formats supporting subdatasets. Note: The valid formats for the output of gdalwarp are formats that support the Create() method (marked as rw+), not just the CreateCopy() method.
 #' @param format Character. List detailed information about a single format driver. The format should be the short name reported in the --formats list, such as GTiff.
 #' @param optfile Character. Read the named file and substitute the contents into the commandline options list. Lines beginning with # will be ignored. Multi-word arguments may be kept together with double quotes.
 #' @param config Character. Sets the named configuration keyword to the given value, as opposed to setting them as environment variables. Some common configuration keywords are GDAL_CACHEMAX (memory used internally for caching in megabytes) and GDAL_DATA (path of the GDAL "data" directory). Individual drivers may be influenced by other configuration options.
 #' @param debug Character. Control what debugging messages are emitted. A value of ON will enable all debug messages. A value of OFF will disable all debug messages. Another value will select only debug messages containing that string in the debug prefix code.
-#' @param additional_commands Character. Additional commands to pass directly to gdalinfo.
+## @param additional_commands Character. Additional commands to pass directly to gdalinfo.
 #' @param raw_output Logical. Dump the raw output of the gdalinfo (default=TRUE). If not, attempt to return a clean list (not all parameters will be retained, at present). 
 #' @param ignore.full_scan Logical. If FALSE, perform a brute-force scan if other installs are not found.  Default is TRUE.
 #' @param verbose Logical. Enable verbose execution? Default is FALSE.  
@@ -60,19 +61,20 @@
 #' # gdalinfo tahoe_highrez.tif
 #' gdalinfo(src_dataset,verbose=TRUE)
 #' }
+#' @importFrom utils glob2rx
 #' @export
 
 gdalinfo <- function(datasetname,mm,stats,
-	approx_stats,hist,nogcp,nomd,nrat,noct,nofl,checksum,
-	proj4,mdd,sd,
-	version,formats,format,optfile,config,debug,
-	additional_commands,
-	raw_output=TRUE,
-	ignore.full_scan=TRUE,
-	verbose=FALSE)
+		approx_stats,hist,nogcp,nomd,nrat,noct,nofl,checksum,
+		proj4,oo,mdd,sd,
+		version,formats,format,optfile,config,debug,
+#		additional_commands,
+		raw_output=TRUE,
+		ignore.full_scan=TRUE,
+		verbose=FALSE)
 {
 	parameter_values <- as.list(environment())
-
+	
 	if(verbose) message("Checking gdal_installation...")
 	gdal_setInstallation(ignore.full_scan=ignore.full_scan,verbose=verbose)
 	if(is.null(getOption("gdalUtils_gdalPath"))) return()
@@ -89,7 +91,7 @@ gdalinfo <- function(datasetname,mm,stats,
 					varnames <- c("sd")),
 			character = list(
 					varnames <- c("mdd","datasetname",
-						"format","optfile","config","debug")),
+							"format","optfile","config","debug","oo")),
 			repeatable = list(
 					varnames <- NULL)
 	)
@@ -97,7 +99,7 @@ gdalinfo <- function(datasetname,mm,stats,
 	parameter_order <- c(
 			"mm","stats","approx_stats","hist","nogcp","nomd","nrat","noct","nofl","checksum",
 			"proj4","mdd","sd",
-			"version","formats","format","optfile","config","debug",
+			"version","formats","format","optfile","config","debug","oo",
 			"datasetname")
 	
 	parameter_noflags <- c("datasetname")
@@ -129,11 +131,20 @@ gdalinfo <- function(datasetname,mm,stats,
 	{
 		result <- list()
 		
+		# browser()
+		
 		# Raster size (in pixels and lines).
 		dims          <- strsplit(gsub(grep(cmd_output,pattern="Size is ",value=TRUE), pattern="Size is ",replacement=""),",")[[1]]
 		result$rows   <- as.numeric(dims[2])
 		result$columns<- as.numeric(dims[1])
 		
+		# Bands!
+		bands <- grep(cmd_output,pattern="Band ",value=TRUE)
+		if(length(bands)==0) result$bands=1 else
+		{
+			result$bands <- length(bands)
+		}
+		
 		orig          <- as.numeric(strsplit(gsub(strsplit(grep(cmd_output,pattern="Lower Left  \\(",value=TRUE), "\\) \\(")[[1]][1],pattern="Lower Left  \\(",replacement=""),",")[[1]])
 		result$ll.x   <- orig[1]
 		result$ll.y   <- orig[2]
@@ -144,7 +155,12 @@ gdalinfo <- function(datasetname,mm,stats,
 		
 		result$file <- gsub(grep(cmd_output,pattern="Files: ",value=TRUE),pattern="Files: ",replacement="")
 		
-		
+		if(!missing(proj4))
+		{
+			# Thanks to http://haotu.wordpress.com/2011/12/02/trim-remove-trailing-and-leading-spaces-from-a-character-string-in-r/
+			# for hints.
+			if(proj4) result$proj4 <- sub("\\s+$","",gsub("'","",cmd_output[grep(pattern="PROJ.4 string is:",cmd_output)+1]))			
+		}
 #		result$oblique.x <- NA
 #		result$oblique.y <- NA
 		
@@ -153,22 +169,30 @@ gdalinfo <- function(datasetname,mm,stats,
 		
 		# The coordinate system for the file (in OGC WKT).
 		# TODO
-	
+		
 		# The geotransform associated with the file (rotational coefficients are currently not reported).
 		# TODO
-	
+		
 		# Corner coordinates in georeferenced, and if possible lat/long based on the full geotransform (but not GCPs).
-		# TODO
+		ul <- as.numeric(strsplit(strsplit(strsplit(cmd_output[grep(pattern=glob2rx("Upper Left*"),cmd_output)],"\\(")[[1]][2],"\\)")[[1]][1],",")[[1]])
+		ll <- as.numeric(strsplit(strsplit(strsplit(cmd_output[grep(pattern=glob2rx("Lower Left*"),cmd_output)],"\\(")[[1]][2],"\\)")[[1]][1],",")[[1]])
+		ur <- as.numeric(strsplit(strsplit(strsplit(cmd_output[grep(pattern=glob2rx("Upper Right*"),cmd_output)],"\\(")[[1]][2],"\\)")[[1]][1],",")[[1]])
+		lr <- as.numeric(strsplit(strsplit(strsplit(cmd_output[grep(pattern=glob2rx("Lower Right*"),cmd_output)],"\\(")[[1]][2],"\\)")[[1]][1],",")[[1]])
+		corners_rbind <- rbind(ul,ll,ur,lr)
+		
+		result$bbox <- matrix(c(min(corners_rbind[,1]),max(corners_rbind[,1]),min(corners_rbind[,2]),max(corners_rbind[,2])),nrow=2,ncol=2,byrow=TRUE)
+		colnames(result$bbox) <- c("min","max")
+		rownames(result$bbox) <- c("s1","s2")
 	
 		# Ground control points.
 		# TODO
 		
 		# File wide (including subdatasets) metadata.
 		# TODO
-	
+		
 		# Band data types.
 		# TODO
-	
+		
 		# Band color interpretations.
 		# TODO	
 		
@@ -183,20 +207,20 @@ gdalinfo <- function(datasetname,mm,stats,
 		
 		# Band checksum (if computation asked).
 		# TODO
-
+		
 		# Band NODATA value.
 		# TODO
-
+		
 		# Band overview resolutions available.
 		# TODO
-
+		
 		# Band unit type (i.e.. "meters" or "feet" for elevation bands).
 		# TODO
-
+		
 		# Band pseudo-color tables.
 		# TODO	
-	
+		
 		return(result)
-	
+		
 	}	
 }
